/* This file is part of Chunky Monkey IRCD 
 *
 * Chunky Monkey IRCD is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Chunky Monkey IRCD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Chunky Monkey IRCD; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * $Id: cmd_version.c,v 1.6.4.5 2002/04/02 11:33:18 lloydy Exp $
 *
 */
#include "modules.h"

CMIRCD_MODULE(1.02, CMD_CLIENT);

/*
 * Return a count of the users on this server
 * or forward it to another server
 */
int cmd_version(ClientInfo c_ptr, ServerInfo s_ptr, Cmd cmd)
{
	ClientInfo source = NULL;
	ServerInfo dest = NULL;
	char buffer[BUF_SIZE];

	if (s_ptr) {
		if (cmd->origin) {
			source = client_locate(cmd->origin);
		}
		if (!source) {
			return 0;
		}
	} else {
		source = c_ptr;
	}

	/* Look for destination */
	if (cmd->params[0]) {

		/* Try and forward */
		dest = server_locate(cmd->params[0]);

		if (dest) {

			if (dest != get_my_server()) {

				ircd_sprintf(buffer, BUF_SIZE,
					     "VERSION %s", dest->name);

				send_origin_server(dest, source->nick,
						   buffer);
			} else {
				ircd_sprintf(buffer, BUF_SIZE,
					     "monkeyircd-%s.(%s %s) %s :TS/V4",
					     VERSION, __TIME__, __DATE__,
					     get_my_server()->name);

				send_numeric(source, get_my_server(), 351,
					     buffer);
			}
		} else {
			ircd_sprintf(buffer, BUF_SIZE,
				     "%s :No Such Server", cmd->params[0]);
			send_numeric(source, get_my_server(), 402, buffer);
		}
	} else {
		ircd_sprintf(buffer, BUF_SIZE,
			     "monkeyircd-%s.(%s %s) %s :TS/V4", VERSION,
			     __TIME__, __DATE__, get_my_server()->name);

		send_numeric(source, get_my_server(), 351, buffer);
	}

	return 1;
}
